@@ -10,6 +10,11 @@ import aioredis
 
 {%- if cookiecutter.orm == "ormar" %}
 from {{cookiecutter.project_name}}.db.config import database
+{%- if cookiecutter.db_info.name != "none" and cookiecutter.enable_migrations == "False" %}
+from sqlalchemy.engine import create_engine
+from {{cookiecutter.project_name}}.db.meta import meta
+from {{cookiecutter.project_name}}.db.models import load_all_models
+{%- endif %}
 {%- endif %}
 
 {%- if cookiecutter.orm == "sqlalchemy" %}
@@ -21,6 +26,11 @@ from sqlalchemy.ext.asyncio import (
 )
 from sqlalchemy.orm import sessionmaker
 
+{%- if cookiecutter.db_info.name != "none" and cookiecutter.enable_migrations == "False" %}
+from {{cookiecutter.project_name}}.db.meta import meta
+from {{cookiecutter.project_name}}.db.models import load_all_models
+{%- endif %}
+
 
 def _setup_db(app: FastAPI) -> None:
     """
@@ -47,11 +57,34 @@ def _setup_db(app: FastAPI) -> None:
 
 {% if cookiecutter.enable_redis == "True" %}
 def _setup_redis(app: FastAPI) -> None:
+    """
+    Initialize redis connection.
+
+    :param app: current FastAPI app.
+    """
     app.state.redis_pool = aioredis.ConnectionPool.from_url(
         str(settings.redis_url),
     )
 {%- endif %}
 
+{%- if cookiecutter.db_info.name != "none" and cookiecutter.enable_migrations == "False" %}
+{%- if cookiecutter.orm in ["ormar", "sqlalchemy"] %}
+async def _create_tables() -> None:
+    """Populates tables in the database."""
+    load_all_models()
+    {%- if cookiecutter.orm == "ormar" %}
+    engine = create_engine(str(settings.db_url))
+    with engine.connect() as connection:
+        meta.create_all(connection)
+    engine.dispose()
+    {%- elif cookiecutter.orm == "sqlalchemy" %}
+    engine = create_async_engine(str(settings.db_url))
+    async with engine.begin() as connection:
+        await connection.run_sync(meta.create_all)
+    await engine.dispose()
+    {%- endif %}
+{%- endif %}
+{%- endif %}
 
 def startup(app: FastAPI) -> Callable[[], Awaitable[None]]:
     """
@@ -67,9 +100,14 @@ def startup(app: FastAPI) -> Callable[[], Awaitable[None]]:
     async def _startup() -> None:  # noqa: WPS430
         {%- if cookiecutter.orm == "sqlalchemy" %}
         _setup_db(app)
-        {% elif cookiecutter.orm == "ormar" %}
+        {%- elif cookiecutter.orm == "ormar" %}
         await database.connect()
         {%- endif %}
+        {%- if cookiecutter.db_info.name != "none" and cookiecutter.enable_migrations == "False" %}
+        {%- if cookiecutter.orm in ["ormar", "sqlalchemy"] %}
+        await _create_tables()
+        {%- endif %}
+        {%- endif %}
         {%- if cookiecutter.enable_redis == "True" %}
         _setup_redis(app)
         {%- endif %}
